@@ -1,6 +1,9 @@
 package MySQL::Sandbox::Recipes;
 
-our $VERSION="3.1.05";
+use strict;
+use warnings;
+
+our $VERSION=q{3.1.06};
 
 1;
 __END__
