@@ -17,7 +17,7 @@ our @EXPORT_OK = qw(
     );
 our @EXPORT = @EXPORT_OK;
 
-our $VERSION="3.1.05";
+our $VERSION=q{3.1.06};
 
 our @MANIFEST = (
 'clear.sh',
@@ -31,6 +31,7 @@ our @MANIFEST = (
 'load_grants.sh',
 'use.sh',
 'mycli.sh',
+'mysqlsh.sh',
 'proxy_start.sh',
 'my.sh',
 'change_paths.sh',
@@ -308,6 +309,15 @@ my %parse_options_low_level_make_sandbox = (
                                             'configures the server for high performance'
                                          ]
                             },
+    gtid            => {
+                                value => 0,      
+                                parse => 'gtid', 
+                                so    => 127,
+                                export => 1,
+                                help  => [
+                                            'enables GTID for MySQL 5.6.10+'
+                                         ]
+                            },
     prompt_prefix           => {
                                 value => 'mysql',      
                                 parse => 'prompt_prefix=s', 
@@ -596,6 +606,16 @@ my %parse_options_replication = (
                                             '(Default: "" )'
                                          ]
                             },
+     gtid      => {
+                                value => 0,
+                                parse => 'gtid'  ,              
+                                so    => 140,
+                                help  => [
+                                            'Enables GTID for MYSQL 5.6.10+',
+                                            '(Default: NO )'
+                                         ]
+                            },
+  
   
     interactive           => {
                                 value => 0,                  
@@ -744,6 +764,16 @@ my %parse_options_many = (
                                             '(Default: "" )'
                                          ]
                             },
+     gtid      => {
+                                value => 0,
+                                parse => 'gtid'  ,              
+                                so    => 150,
+                                help  => [
+                                            'Enables GTID for MYSQL 5.6.10+',
+                                            '(Default: NO )'
+                                         ]
+                            },
+  
 
     interactive           => {
                                 value => 0,                  
@@ -1300,6 +1330,16 @@ export DYLD_LIBRARY_PATH=_BASEDIR_/lib:_BASEDIR_/lib/mysql:$DYLD_LIBRARY_PATH
 SBDIR="_HOME_DIR_/_SANDBOXDIR_"
 BASEDIR=_BASEDIR_
 [ -z "$MYSQL_EDITOR" ] && MYSQL_EDITOR="$BASEDIR/bin/mysql"
+if [ ! -x $MYSQL_EDITOR ]
+then
+    if [ -x $SBDIR/$MYSQL_EDITOR ]
+    then
+        MYSQL_EDITOR=$SBDIR/$MYSQL_EDITOR
+    else
+        echo "MYSQL_EDITOR '$MYSQL_EDITOR' not found or not executable"
+        exit 1
+    fi
+fi
 HISTDIR=_HISTORY_DIR_
 [ -z "$HISTDIR" ] && HISTDIR=$SBDIR
 export MYSQL_HISTFILE="$HISTDIR/.mysql_history"
@@ -1329,6 +1369,23 @@ mycli --user=_DBUSER_ \
 MYCLI_SCRIPT
 
 
+    'mysqlsh.sh' => <<'MYSQLSH_SCRIPT',
+#!_BINBASH_
+__LICENSE__
+export LD_LIBRARY_PATH=_BASEDIR_/lib:_BASEDIR_/lib/mysql:$LD_LIBRARY_PATH
+export DYLD_LIBRARY_PATH=_BASEDIR_/lib:_BASEDIR_/lib/mysql:$DYLD_LIBRARY_PATH
+SBDIR="_HOME_DIR_/_SANDBOXDIR_"
+BASEDIR=_BASEDIR_
+mysqlsh \
+    --sqlc \
+    --user=_DBUSER_ \
+    --password=_DBPASSWORD_ \
+    --port=_SERVERPORT_ \
+    --socket=_GLOBALTMPDIR_/mysql_sandbox_SERVERPORT_.sock "$@"
+
+MYSQLSH_SCRIPT
+
+
     'clear.sh' => <<'CLEAR_SCRIPT', 
 #!_BINBASH_
 __LICENSE__
@@ -1979,9 +2036,14 @@ fi
 $MASTER -e 'create schema if not exists test'
 $MASTER test -e 'drop table if exists t1'
 $MASTER test -e 'create table t1 (i int not null primary key, msg varchar(50), d date, t time, dt datetime, ts timestamp)'
-$MASTER test -e "insert into t1 values (1, 'test sandbox 1', '2015-07-16', '11:23:40','2015-07-17 12:34:50', null)"
+#$MASTER test -e "insert into t1 values (1, 'test sandbox 1', '2015-07-16', '11:23:40','2015-07-17 12:34:50', null)"
+#$MASTER test -e "insert into t1 values (2, 'test sandbox 2', '2015-07-17', '11:23:41','2015-07-17 12:34:51', null)"
+for N in $(seq -f '%02.0f' 1 20)
+do
+    #echo "$MASTER test -e \"insert into t1 values ($N, 'test sandbox $N', '2015-07-$N', '11:23:$N','2015-07-17 12:34:$N', null)\""
+    $MASTER test -e "insert into t1 values ($N, 'test sandbox $N', '2015-07-$N', '11:23:$N','2015-07-17 12:34:$N', null)"
+done
 sleep 0.5
-$MASTER test -e "insert into t1 values (2, 'test sandbox 2', '2015-07-17', '11:23:41','2015-07-17 12:34:51', null)"
 MASTER_RECS=$($MASTER -BN -e 'select count(*) from test.t1')
 
 master_status=master_status$$
@@ -2024,6 +2086,13 @@ function test_summary
         printf "# FAILED: %5d (%5.1f%%)\n" $FAILED $PERCENT_FAILED
         printf "# PASSED: %5d (%5.1f%%)\n" $PASSED $PERCENT_PASSED
     fi
+    exit_code=0
+    if [ "$FAILED" != "0" ]
+    then
+        exit_code=1
+    fi
+    echo "# exit code: $exit_code"
+    exit $exit_code
 }
 
 for SLAVE_N in 1 2 3 4 5 6 7 8 9
