@@ -16,8 +16,15 @@ BEGIN {
     $ENV{TEST_SANDBOX_HOME}="$ENV{PWD}/t/test_sb";
     $ENV{PERL5LIB}="$ENV{PWD}/lib";
     $ENV{PATH}="$ENV{PWD}/bin:$ENV{PATH}";
-    $ENV{TEST_VERSION} = $ENV{TEST_VERSION} || '5.6.26';
+    $ENV{TEST_VERSION} = $ENV{TEST_VERSION} || '5.6.29';
     $ENV{SANDBOX_AS_ROOT} = 1;
+    for my $env_var (qw(NODE_OPTIONS MASTER_OPTIONS SLAVE_OPTIONS))
+    {
+        if ($ENV{$env_var})
+        {
+            $ENV{$env_var} = undef;
+        }
+    }
     $test_version = $ENV{TEST_VERSION} ;
 };
 
